@@ -20,7 +20,7 @@ class UndefinedUncertainty(UncertaintyBase):
 
     @classmethod
     def ppf(cls, params, percentages):
-        return tile(params['amount'].reshape(params.shape[0], 1), 
+        return tile(params['amount'].reshape((params.shape[0], 1)), 
             percentages.shape[1])
 
 
